@@ -2,8 +2,6 @@ from typing import List
 
 import numpy as np
 from napari.layers import Layer
-from qtpy.QtCore import QEvent
-from qtpy.QtWidgets import QToolTip
 from vispy.app import MouseEvent
 
 from ..common_gui.channel_control import ChannelProperty
@@ -43,7 +41,11 @@ class StackImageView(ImageView):
             translate_grid[image_info.image.stack_pos] = 0
             self.additional_layers.append(
                 self.viewer.add_image(
-                    component_mark, scale=image_info.roi.scale, blending="additive", colormap="gray", opacity=0.5,
+                    component_mark,
+                    scale=image_info.roi.scale,
+                    blending="additive",
+                    colormap="gray",
+                    opacity=0.5,
                 )
             )
             self.additional_layers[-1].translate_grid = translate_grid
@@ -62,14 +64,14 @@ class StackImageView(ImageView):
             if component:
                 self.component_clicked.emit(component)
 
-    def event(self, event: QEvent):
-        if event.type() == QEvent.ToolTip and self.components:
-            # text = str(self.component)
-            text_list = []
-            for el in self.components:
-                if self.settings.component_is_chosen(el):
-                    text_list.append("☑{}".format(el))
-                else:
-                    text_list.append("☐{}".format(el))
-            QToolTip.showText(event.globalPos(), " ".join(text_list))
-        return super().event(event)
+    def get_tool_tip_text(self) -> str:
+        text = super().get_tool_tip_text()
+        text_list = []
+        for el in self.components:
+            if self.settings.component_is_chosen(el):
+                text_list.append("☑{}".format(el))
+            else:
+                text_list.append("☐{}".format(el))
+        if text:
+            return " ".join(text_list) + "\n" + text
+        return " ".join(text_list)
