@@ -79,7 +79,12 @@ class MaskDialog(MaskDialogBase):
         self.settings.set("mask_manager.mask_property", mask_property)
         mask = calculate_mask_from_project(mask_description=mask_property, project=project_info)
 
-        self.settings.add_history_element(create_history_element_from_segmentation_tuple(project_info, mask_property,))
+        self.settings.add_history_element(
+            create_history_element_from_segmentation_tuple(
+                project_info,
+                mask_property,
+            )
+        )
         self.settings.mask = mask
         self.settings.chosen_components_widget.un_check_all()
         self.close()
@@ -175,14 +180,18 @@ class MainMenu(BaseMainMenu):
         # TODO move segmentation with image load to load_segmentaion
         dial = CustomLoadDialog(io_functions.load_dict)
         dial.setDirectory(self.settings.get("io.load_image_directory", str(Path.home())))
+        default_file_path = self.settings.get("io.load_image_file", "")
+        if os.path.isfile(default_file_path):
+            dial.selectFile(default_file_path)
         dial.selectNameFilter(self.settings.get("io.load_data_filter", next(iter(io_functions.load_dict.keys()))))
         dial.setHistory(dial.history() + self.settings.get_path_history())
         if not dial.exec_():
             return
         load_property = dial.get_result()
         self.settings.set("io.load_image_directory", os.path.dirname(load_property.load_location[0]))
+        self.settings.set("io.load_image_file", load_property.load_location[0])
         self.settings.set("io.load_data_filter", load_property.selected_filter)
-        self.settings.add_path_history(os.path.dirname(load_property.load_location[0]))
+        self.settings.add_load_files_history(load_property.load_location, load_property.load_class.get_name())
 
         def exception_hook(exception):
             if isinstance(exception, ValueError) and exception.args[0] == "not a TIFF file":
@@ -675,7 +684,11 @@ class AlgorithmOptions(QWidget):
         self._execute_in_background_init()
 
     def execute_all_action(self):
-        dial = SaveDialog({SaveROI.get_name(): SaveROI}, history=self.settings.get_path_history(), system_widget=False,)
+        dial = SaveDialog(
+            {SaveROI.get_name(): SaveROI},
+            history=self.settings.get_path_history(),
+            system_widget=False,
+        )
         dial.setFileMode(QFileDialog.Directory)
         dial.setDirectory(self.settings.get("io.save_batch", self.settings.get("io.save_segmentation_directory", "")))
         if not dial.exec_():
@@ -872,7 +885,7 @@ class MainWindow(BaseMainWindow):
     def __init__(
         self, config_folder=CONFIG_FOLDER, title="PartSeg", settings=None, signal_fun=None, initial_image=None
     ):
-        super().__init__(config_folder, title, settings, signal_fun)
+        super().__init__(config_folder, title, settings, io_functions.load_dict, signal_fun)
         self.channel_info = "channelcontrol"
         self.channel_control = ChannelProperty(self.settings, start_name="channelcontrol")
         self.image_view = StackImageView(self.settings, self.channel_control, name="channelcontrol")
@@ -890,7 +903,6 @@ class MainWindow(BaseMainWindow):
         self.options_panel.algorithm_options.batch_process.multiple_result.connect(
             partial(self.multiple_files.save_state_action, custom_name=False)
         )
-        self.options_panel.image_properties.multiple_files.stateChanged.connect(self.multiple_files.setVisible)
 
         icon = QIcon(os.path.join(PartSegData.icons_dir, "icon_stack.png"))
         self.setWindowIcon(icon)
@@ -898,6 +910,7 @@ class MainWindow(BaseMainWindow):
         menu_bar = self.menuBar()
         file_menu = menu_bar.addMenu("File")
         file_menu.addAction("&Open").triggered.connect(self.main_menu.load_image)
+        file_menu.addMenu(self.recent_file_menu)
         file_menu.addAction("&Save segmentation").triggered.connect(self.main_menu.save_segmentation)
         file_menu.addAction("&Save components").triggered.connect(self.main_menu.save_result)
         view_menu = menu_bar.addMenu("View")
@@ -949,10 +962,6 @@ class MainWindow(BaseMainWindow):
         except KeyError:
             pass
 
-    def image_read(self):
-        self.image_view.reset_image_size()
-        self.setWindowTitle(f"{self.title_base}: {os.path.basename(self.settings.image_path)}")
-
     def closeEvent(self, event: QCloseEvent):
         self.settings.set_in_profile("main_window_geometry", self.saveGeometry().toHex().data().decode("ascii"))
         self.options_panel.algorithm_options.algorithm_choose_widget.recursive_get_values()
@@ -969,9 +978,6 @@ class MainWindow(BaseMainWindow):
         self.settings.dump()
         super().closeEvent(event)
 
-    def read_drop(self, paths):
-        self._read_drop(paths, io_functions)
-
     @staticmethod
     def get_project_info(file_path, image):
         return MaskProjectTuple(file_path=file_path, image=image)
