@@ -5,13 +5,14 @@ import sys
 import warnings
 from datetime import datetime
 from pathlib import Path
-from typing import Dict, List, NamedTuple, Optional, Tuple, Union
+from typing import Any, Dict, List, NamedTuple, Optional, Tuple, Union
 
 import napari.utils.theme
 import numpy as np
 from napari.resources import get_stylesheet
 from napari.utils.theme import template as napari_template
 from qtpy.QtCore import QObject, Signal
+from qtpy.QtWidgets import QMessageBox, QWidget
 
 from PartSeg.common_backend.partially_const_dict import PartiallyConstDict
 from PartSegCore.color_image import ColorMap, default_colormap_dict, default_label_dict
@@ -20,9 +21,12 @@ from PartSegCore.io_utils import HistoryElement, load_metadata_base
 from PartSegCore.json_hooks import ProfileDict, ProfileEncoder, check_loaded_dict
 from PartSegCore.project_info import ProjectInfoBase
 from PartSegCore.roi_info import ROIInfo
-from PartSegCore.segmentation.algorithm_base import AdditionalLayerDescription
+from PartSegCore.segmentation.algorithm_base import AdditionalLayerDescription, SegmentationResult
 from PartSegImage import Image
 
+DIR_HISTORY = "io.dir_location_history"
+FILE_HISTORY = "io.files_open_history"
+
 
 class ImageSettings(QObject):
     """
@@ -44,9 +48,12 @@ class ImageSettings(QObject):
         super().__init__()
         self._image: Optional[Image] = None
         self._image_path = ""
-        self._image_spacing = 210, 70, 70
         self._roi_info = ROIInfo(None)
         self._additional_layers = {}
+        self._parent: Optional[QWidget] = None
+
+    def set_parent(self, parent: QWidget):
+        self._parent = parent
 
     @property
     def full_segmentation(self):
@@ -58,20 +65,19 @@ class ImageSettings(QObject):
 
     @property
     def noise_remove_image_part(self):
-        raise AttributeError("full_segmentation not supported")
+        raise AttributeError("noise_remove_image_part not supported")
 
     @noise_remove_image_part.setter
     def noise_remove_image_part(self, val):  # pylint: disable=R0201
-        raise AttributeError("full_segmentation not supported")
+        raise AttributeError("noise_remove_image_part not supported")
 
     @property
     def additional_layers(self) -> Dict[str, AdditionalLayerDescription]:
         return self._additional_layers
 
     @additional_layers.setter
-    def additional_layers(self, val: Dict[str, AdditionalLayerDescription]):
-        self._additional_layers = val
-        self.additional_layers_changed.emit()
+    def additional_layers(self, val):  # pylint: disable=R0201
+        raise AttributeError("additional_layers assign not supported")
 
     @property
     def image_spacing(self):
@@ -115,17 +121,21 @@ class ImageSettings(QObject):
         return self._roi_info
 
     @roi.setter
-    def roi(self, val: np.ndarray):
-        if val is not None:
-            try:
-                val = self.image.fit_array_to_image(val)
-            except ValueError:
-                raise ValueError("roi do not fit to image")
-        self._roi_info = ROIInfo(val)
-        if val is not None:
-            self.roi_changed.emit(self._roi_info)
-        else:
+    def roi(self, val: Union[np.ndarray, ROIInfo]):
+        if val is None:
+            self._roi_info = ROIInfo(val)
+            self._additional_layers = {}
             self.roi_clean.emit()
+            return
+        try:
+            if isinstance(val, np.ndarray):
+                self._roi_info = ROIInfo(self.image.fit_array_to_image(val))
+            else:
+                self._roi_infol = val.fit_to_image(self.image)
+        except ValueError:
+            raise ValueError("roi do not fit to image")
+        self._additional_layers = {}
+        self.roi_changed.emit(self._roi_info)
 
     @property
     def sizes(self):
@@ -225,6 +235,8 @@ class ViewSettings(ImageSettings):
     colormap_changes = Signal()
     labels_changed = Signal()
     theme_changed = Signal()
+    profile_data_changed = Signal(str, object)
+    """Signal about changes in stored data (set with set_in_profile)"""
 
     def __init__(self):
         super().__init__()
@@ -308,7 +320,7 @@ class ViewSettings(ImageSettings):
         # TODO update sorting rule
         self.chosen_colormap = list(sorted(colormaps, key=self.colormap_dict.get_position))
 
-    def get_channel_info(self, view: str, num: int, default: Optional[str] = None) -> List[str]:
+    def get_channel_info(self, view: str, num: int, default: Optional[str] = None) -> str:
         cm = self.chosen_colormap
         if default is None:
             default = cm[num % len(cm)]
@@ -340,8 +352,9 @@ class ViewSettings(ImageSettings):
         :py:meth:`~.ProfileDict.set` of inner variable.
 
         :param key_path: dot separated path
-        :param value: value to store. The value need to be json serializable. """
+        :param value: value to store. The value need to be json serializable."""
         self.view_settings_dict.set(f"{self.current_profile_dict}.{key_path}", value)
+        self.profile_data_changed.emit(key_path, value)
 
     def get_from_profile(self, key_path, default=None):
         """
@@ -380,6 +393,7 @@ class BaseSettings(ViewSettings):
     algorithm_changed = Signal()
     """:py:class:`~.Signal` emitted when current algorithm should be changed"""
     save_locations_keys = []
+    data_changed = Signal(str, object)
 
     def __init__(self, json_path):
         super().__init__()
@@ -389,6 +403,24 @@ class BaseSettings(ViewSettings):
         self.last_executed_algorithm = ""
         self.history: List[HistoryElement] = []
         self.history_index = -1
+        self.last_executed_algorithm = ""
+
+    def set_segmentation_result(self, result: SegmentationResult):
+        if result.info_text and self._parent is not None:
+            QMessageBox().information(self._parent, "Algorithm info", result.info_text)
+
+        self._additional_layers = result.additional_layers
+        self.last_executed_algorithm = result.parameters.algorithm
+        self.set(f"algorithms.{result.parameters.algorithm}", result.parameters.values)
+        try:
+            roi = self.image.fit_array_to_image(result.roi)
+            alternative_list = {
+                k: self.image.fit_array_to_image(v) for k, v in result.alternative_representation.items()
+            }
+        except ValueError:
+            raise ValueError("roi do not fit to image")
+        self._roi_info = ROIInfo(roi, result.roi_annotation, alternative_list)
+        self.roi_changed.emit(self._roi_info)
 
     def _load_files_call(self, files_list: List[str]):
         self.request_load_files.emit(files_list)
@@ -462,22 +494,31 @@ class BaseSettings(ViewSettings):
         return list containing last 10 elements added with :py:meth:`.add_path_history` and
         last opened in each category form :py:attr:`save_location_keys`
         """
-        res = self.get("io.history", [])[:]
+        res = self.get(DIR_HISTORY, [])[:]
         for name in self.save_locations_keys:
             val = self.get("io." + name, str(Path.home()))
             if val not in res:
                 res = res + [val]
         return res
 
+    def get_last_files(self) -> list:
+        return self.get(FILE_HISTORY, [])
+
+    @staticmethod
+    def _add_elem_to_list(data_list: list, value: Any) -> list:
+        try:
+            data_list.remove(value)
+        except ValueError:
+            data_list = data_list[:9]
+        return [value] + data_list
+
     def add_path_history(self, dir_path: str):
         """Save path in history of visited directories. Store only 10 last"""
-        history: List[str] = self.get("io.history", [])
-        try:
-            history.remove(dir_path)
-        except ValueError:
-            history = history[:9]
+        self.set(DIR_HISTORY, self._add_elem_to_list(self.get(DIR_HISTORY, []), dir_path))
 
-        self.set("io.history", [dir_path] + history[-9:])
+    def add_load_files_history(self, file_path: List[str], load_method: str):
+        self.set(FILE_HISTORY, self._add_elem_to_list(self.get(FILE_HISTORY, []), (file_path, load_method)))
+        self.add_path_history(os.path.dirname(file_path[0]))
 
     def set(self, key_path: str, value):
         """
@@ -486,8 +527,9 @@ class BaseSettings(ViewSettings):
 
         :param key_path: dot separated path
         :param value: value to store. The value need to be json serializable.
-         """
+        """
         self._roi_dict.set(f"{self._current_roi_dict}.{key_path}", value)
+        self.data_changed.emit(key_path, value)
 
     def get(self, key_path: str, default=None):
         """
@@ -592,8 +634,7 @@ class BaseSettings(ViewSettings):
                 raise TimeAndStackException()
             if silent:
                 return image.swap_time_and_stack()
-            else:
-                raise SwapTimeStackException()
+            raise SwapTimeStackException()
         return True
 
 
