@@ -1,24 +1,25 @@
 import json
 import sys
-from urllib import request, error
+from urllib import error, request
 
 import packaging.version
 import sentry_sdk
+from qtpy.QtCore import QThread, Slot
 from qtpy.QtGui import QIcon
-from qtpy.QtCore import Slot, QThread
 from qtpy.QtWidgets import QApplication, QMessageBox
 
 from PartSegCore import state_store
-from PartSegImage import TiffFileException
 from PartSegCore.segmentation.algorithm_base import SegmentationLimitException
+from PartSegImage import TiffFileException
+
 from .. import __version__
 
 
 class CheckVersionThread(QThread):
     """Thread to check if there is new PartSeg release. Checks base on newest version available on pypi_
 
-     .. _PYPI: https://pypi.org/project/PartSeg/
-     """
+    .. _PYPI: https://pypi.org/project/PartSeg/
+    """
 
     def __init__(self):
         super().__init__()
@@ -30,14 +31,17 @@ class CheckVersionThread(QThread):
 
         # noinspection PyBroadException
         try:
-            r = request.urlopen("https://pypi.org/pypi/PartSeg/json")
+            r = request.urlopen("https://pypi.org/pypi/PartSeg/json")  # nosec
             data = json.load(r)
             self.release = data["info"]["version"]
             self.url = data["info"]["home_page"]
         except (KeyError, error.URLError):
             pass
         except Exception as e:
-            sentry_sdk.capture_exception(e)
+            with sentry_sdk.push_scope() as scope:
+                scope.set_tag("auto_report", "true")
+                scope.set_tag("check_version", "true")
+                sentry_sdk.capture_exception(e)
 
 
 class CustomApplication(QApplication):
