@@ -127,6 +127,7 @@ class MeasurementCalculate(BaseSerializableClass):
 
     # noinspection PyOverloads,PyMissingConstructor
     # pylint: disable=W0104
+    # pragma: no cover
     @typing.overload
     def __init__(self, channel: int, units: Units, measurement_profile: MeasurementProfile, name_prefix: str):
         ...
@@ -182,7 +183,7 @@ class MaskMapper:
 
     @abstractmethod
     def get_parameters(self):
-        pass
+        """Parameters for serialize"""
 
     @staticmethod
     def is_ready() -> bool:
@@ -203,7 +204,7 @@ class MaskSuffix(MaskMapper, BaseSerializableClass):
     # noinspection PyMissingConstructor,PyOverloads
     # pylint: disable=W0104
     @typing.overload
-    def __init__(self, name: str, suffix: str):
+    def __init__(self, name: str, suffix: str):  # pragma: no cover
         ...
 
     def get_mask_path(self, file_path: str) -> str:
@@ -229,7 +230,7 @@ class MaskSub(MaskMapper, BaseSerializableClass):
     # noinspection PyMissingConstructor,PyOverloads
     # pylint: disable=W0104
     @typing.overload
-    def __init__(self, name: str, base: str, rep: str):
+    def __init__(self, name: str, base: str, rep: str):  # pragma: no cover
         ...
 
     def get_mask_path(self, file_path: str) -> str:
@@ -249,7 +250,7 @@ class MaskFile(MaskMapper, BaseSerializableClass):
     # noinspection PyMissingConstructor,PyOverloads
     # pylint: disable=W0104
     @typing.overload
-    def __init__(self, name: str, path_to_file: str, name_dict: typing.Optional[dict] = None):
+    def __init__(self, name: str, path_to_file: str, name_dict: typing.Optional[dict] = None):  # pragma: no cover
         ...
 
     def is_ready(self) -> bool:
@@ -512,11 +513,11 @@ class CalculationPlan:
             node = self.execution_tree
         if isinstance(node.operation, MeasurementCalculate):
             return [node.operation]
-        else:
-            res = []
-            for el in node.children:
-                res.extend(self.get_measurements(el))
-            return res
+
+        res = []
+        for el in node.children:
+            res.extend(self.get_measurements(el))
+        return res
 
     def get_changes(self):
         ret = self.changes
@@ -677,11 +678,11 @@ class CalculationPlan:
         """
         if isinstance(node.operation, Save):
             return [node.operation]
-        else:
-            res = []
-            for chl in node.children:
-                res.extend(self._get_save_list(chl))
-            return res
+
+        res = []
+        for chl in node.children:
+            res.extend(self._get_save_list(chl))
+        return res
 
     def get_save_list(self):
         return self._get_save_list(self.execution_tree)
@@ -739,13 +740,11 @@ class CalculationPlan:
         if isinstance(el, MeasurementCalculate):
             if el.name_prefix == "":
                 return "Measurement: {}".format(el.name)
-            else:
-                return "Measurement: {} with prefix: {}".format(el.name, el.name_prefix)
+            return "Measurement: {} with prefix: {}".format(el.name, el.name_prefix)
         if isinstance(el, MaskCreate):
             if el.name != "":
                 return "Create mask: {}".format(el.name)
-            else:
-                return "Create mask:"
+            return "Create mask:"
         if isinstance(el, MaskUse):
             return "Use mask: {}".format(el.name)
         if isinstance(el, MaskSuffix):
@@ -767,13 +766,11 @@ class CalculationPlan:
         if isinstance(el, MaskIntersection):
             if el.name == "":
                 return "Mask intersection of mask {} and {}".format(el.mask1, el.mask2)
-            else:
-                return "Mask {} intersection of mask {} and {}".format(el.name, el.mask1, el.mask2)
+            return "Mask {} intersection of mask {} and {}".format(el.name, el.mask1, el.mask2)
         if isinstance(el, MaskSum):
             if el.name == "":
                 return "Mask sum of mask {} and {}".format(el.mask1, el.mask2)
-            else:
-                return "Mask {} sum of mask {} and {}".format(el.name, el.mask1, el.mask2)
+            return "Mask {} sum of mask {} and {}".format(el.name, el.mask1, el.mask2)
 
         raise ValueError("Unknown type {}".format(type(el)))
 
