@@ -88,14 +88,10 @@ class BorderRim(RestartableAlgorithm):
     def get_fields(cls):
         return ["Need mask"] + BorderRimBase.get_fields()
 
-    def get_segmentation_profile(self) -> ROIExtractionProfile:
-        return ROIExtractionProfile("", self.get_name(), deepcopy(self.new_parameters))
-
     def get_info_text(self):
         if self.mask is None:
             return "Need mask"
-        else:
-            return ""
+        return ""
 
     def calculation_run(self, _report_fun) -> SegmentationResult:
         if self.mask is not None:
@@ -115,10 +111,8 @@ class MaskDistanceSplit(RestartableAlgorithm):
             result = MaskDistanceSplitBase.split(
                 mask=self.mask, voxel_size=self.image.voxel_size, **self.new_parameters
             )
-            return SegmentationResult(result, self.get_segmentation_profile(), result, None)
-
-    def get_segmentation_profile(self) -> ROIExtractionProfile:
-        return ROIExtractionProfile("", self.get_name(), deepcopy(self.new_parameters))
+            return SegmentationResult(roi=result, parameters=self.get_segmentation_profile())
+        raise SegmentationLimitException("Mask Distance Split needs mask")
 
     @classmethod
     def get_name(cls) -> str:
@@ -191,8 +185,13 @@ class ThresholdBaseAlgorithm(RestartableAlgorithm, ABC):
         :param roi: array with segmentation
         :return: algorithm result description
         """
+        sizes = np.bincount(roi.flat)
+        annotation = {i: {"voxels": size} for i, size in enumerate(sizes[1:], 1) if size > 0}
         return SegmentationResult(
-            roi=roi, parameters=self.get_segmentation_profile(), additional_layers=self.get_additional_layers(),
+            roi=roi,
+            parameters=self.get_segmentation_profile(),
+            additional_layers=self.get_additional_layers(),
+            roi_annotation=annotation,
         )
 
     def set_image(self, image):
@@ -368,6 +367,10 @@ class RangeThresholdAlgorithm(ThresholdBaseAlgorithm):
 
 
 class TwoLevelThresholdBaseAlgorithm(ThresholdBaseAlgorithm, ABC):
+    def __init__(self):
+        super().__init__()
+        self.sprawl_area = None
+
     def _threshold(self, image, thr=None):
         if thr is None:
             thr: BaseThreshold = double_threshold_dict[self.new_parameters["threshold"]["name"]]
@@ -427,7 +430,6 @@ class BaseThresholdFlowAlgorithm(TwoLevelThresholdBaseAlgorithm, ABC):
         self.finally_segment = None
         self.final_sizes = []
         self.threshold_info = [None, None]
-        self.sprawl_area = None
 
     def clean(self):
         self.sprawl_area = None
@@ -478,6 +480,10 @@ class BaseThresholdFlowAlgorithm(TwoLevelThresholdBaseAlgorithm, ABC):
                 roi=new_segment,
                 parameters=self.get_segmentation_profile(),
                 additional_layers=self.get_additional_layers(full_segmentation=self.sprawl_area),
+                roi_annotation={
+                    i: {"core voxels": self._sizes_array[i], "voxels": v} for i, v in enumerate(self.final_sizes[1:], 1)
+                },
+                alternative_representation={"core_objects": finally_segment},
             )
 
 
@@ -564,7 +570,7 @@ class OtsuSegment(RestartableAlgorithm):
         )
 
 
-class BaseMultiScaleOpening(TwoLevelThresholdBaseAlgorithm, ABC):
+class BaseMultiScaleOpening(TwoLevelThresholdBaseAlgorithm, ABC):  # pragma: no cover
     @classmethod
     def get_fields(cls):
         return [
@@ -601,7 +607,6 @@ class BaseMultiScaleOpening(TwoLevelThresholdBaseAlgorithm, ABC):
         self.finally_segment = None
         self.final_sizes = []
         self.threshold_info = [None, None]
-        self.sprawl_area = None
         self.steps = 0
         self.mso = PyMSO()
         self.mso.set_use_background(True)
@@ -681,7 +686,7 @@ class LowerThresholdMultiScaleOpening(BaseMultiScaleOpening):
     threshold_operator = staticmethod(operator.gt)
 
     @classmethod
-    def get_name(cls):
+    def get_name(cls):  # pragma: no cover
         return "Lower threshold MultiScale Opening"
 
 
@@ -689,7 +694,7 @@ class UpperThresholdMultiScaleOpening(BaseMultiScaleOpening):
     threshold_operator = staticmethod(operator.lt)
 
     @classmethod
-    def get_name(cls):
+    def get_name(cls):  # pragma: no cover
         return "Upper threshold MultiScale Opening"
 
 
