@@ -1451,7 +1451,7 @@ class TestStatisticProfile:
     def test_cube_volume_area_type(self):
         image = get_cube_image()
         image.set_spacing(tuple([x / UNIT_SCALE[Units.nm.value] for x in image.spacing]))
-        mask = (image.get_channel(0)[0] > 40).astype(np.uint8)
+        image.set_mask((image.get_channel(0)[0] > 40).astype(np.uint8))
         segmentation = (image.get_channel(0)[0] > 60).astype(np.uint8)
 
         statistics = [
@@ -1469,7 +1469,10 @@ class TestStatisticProfile:
         ]
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.µm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.µm,
         )
         tot_vol, seg_vol, rim_vol = list(result.values())
         assert isclose(tot_vol[0], seg_vol[0] + rim_vol[0])
@@ -1478,7 +1481,7 @@ class TestStatisticProfile:
     def test_square_volume_area_type(self):
         image = get_square_image()
         image.set_spacing(tuple([x / UNIT_SCALE[Units.nm.value] for x in image.spacing]))
-        mask = (image.get_channel(0)[0] > 40).astype(np.uint8)
+        image.set_mask((image.get_channel(0)[0] > 40).astype(np.uint8))
         segmentation = (image.get_channel(0)[0] > 60).astype(np.uint8)
 
         statistics = [
@@ -1496,7 +1499,10 @@ class TestStatisticProfile:
         ]
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.µm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.µm,
         )
         tot_vol, seg_vol, rim_vol = list(result.values())
         assert isclose(tot_vol[0], seg_vol[0] + rim_vol[0])
@@ -1505,7 +1511,7 @@ class TestStatisticProfile:
     def test_cube_pixel_sum_area_type(self):
         image = get_cube_image()
         image.set_spacing(tuple([x / UNIT_SCALE[Units.nm.value] for x in image.spacing]))
-        mask = (image.get_channel(0)[0] > 40).astype(np.uint8)
+        image.set_mask((image.get_channel(0)[0] > 40).astype(np.uint8))
         segmentation = (image.get_channel(0)[0] > 60).astype(np.uint8)
 
         statistics = [
@@ -1526,7 +1532,10 @@ class TestStatisticProfile:
         ]
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.µm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.µm,
         )
         tot_vol, seg_vol, rim_vol = list(result.values())
         assert isclose(tot_vol[0], seg_vol[0] + rim_vol[0])
@@ -1534,7 +1543,7 @@ class TestStatisticProfile:
     def test_cube_surface_area_type(self):
         image = get_cube_image()
         image.set_spacing(tuple([x / UNIT_SCALE[Units.nm.value] for x in image.spacing]))
-        mask = (image.get_channel(0)[0] > 40).astype(np.uint8)
+        image.set_mask((image.get_channel(0)[0] > 40).astype(np.uint8))
         segmentation = (image.get_channel(0)[0] > 60).astype(np.uint8)
 
         statistics = [
@@ -1552,7 +1561,10 @@ class TestStatisticProfile:
         ]
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.µm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.µm,
         )
         tot_vol, seg_vol, rim_vol = list(result.values())
         assert isclose(tot_vol[0] + seg_vol[0], rim_vol[0])
@@ -1560,7 +1572,7 @@ class TestStatisticProfile:
     def test_cube_density(self):
         image = get_cube_image()
         image.set_spacing(tuple([x / UNIT_SCALE[Units.nm.value] for x in image.spacing]))
-        mask = (image.get_channel(0)[0] > 40).astype(np.uint8)
+        image.set_mask((image.get_channel(0)[0] > 40).astype(np.uint8))
         segmentation = (image.get_channel(0)[0] > 60).astype(np.uint8)
 
         statistics = [
@@ -1618,7 +1630,10 @@ class TestStatisticProfile:
         ]
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.µm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.µm,
         )
         values = list(result.values())
         for i in range(3):
@@ -1628,7 +1643,7 @@ class TestStatisticProfile:
     def test_cube_volume_power(self):
         image = get_cube_image()
         image.set_spacing(tuple([x / UNIT_SCALE[Units.nm.value] for x in image.spacing]))
-        mask = (image.get_channel(0)[0] > 40).astype(np.uint8)
+        image.set_mask((image.get_channel(0)[0] > 40).astype(np.uint8))
         segmentation = (image.get_channel(0)[0] > 60).astype(np.uint8)
 
         statistics = [
@@ -1654,7 +1669,10 @@ class TestStatisticProfile:
         ]
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.µm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.µm,
         )
         vol1, vol2, vol3, vol4 = list(result.values())
         assert isclose(vol1[0], vol3[0])
@@ -1663,10 +1681,10 @@ class TestStatisticProfile:
 
     def test_per_component_cache_collision(self):
         image = get_two_components_image()
-        mask = get_two_component_mask()
-        segmentation = np.zeros(mask.shape, dtype=np.uint8)
-        segmentation[image.get_channel(0)[0] == 50] = 1
-        segmentation[image.get_channel(0)[0] == 60] = 2
+        image.set_mask(get_two_component_mask())
+        segmentation = np.zeros(image.mask.shape, dtype=np.uint8)
+        segmentation[image.get_channel(0) == 50] = 1
+        segmentation[image.get_channel(0) == 60] = 2
         statistics = [
             MeasurementEntry(
                 "Volume", Volume.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.No)
@@ -1676,7 +1694,8 @@ class TestStatisticProfile:
                 Volume.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.Yes),
             ),
             MeasurementEntry(
-                "Diameter", Diameter.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.No),
+                "Diameter",
+                Diameter.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.No),
             ),
             MeasurementEntry(
                 "Diameter per component",
@@ -1691,7 +1710,8 @@ class TestStatisticProfile:
                 MaximumPixelBrightness.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.Yes),
             ),
             MeasurementEntry(
-                "Sphericity", Sphericity.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.No),
+                "Sphericity",
+                Sphericity.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.No),
             ),
             MeasurementEntry(
                 "Sphericity per component",
@@ -1711,7 +1731,10 @@ class TestStatisticProfile:
 
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.nm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.nm,
         )
         assert result["Volume"][0] == result["Volume per component"][0][0] + result["Volume per component"][0][1]
         assert len(result["Diameter per component"][0]) == 2
@@ -1719,10 +1742,10 @@ class TestStatisticProfile:
         assert result["MaximumPixelBrightness per component"][0] == [50, 60]
         assert result["Sphericity per component"][0] == [
             Sphericity.calculate_property(
-                area_array=segmentation == 1, voxel_size=image.voxel_size, result_scalar=UNIT_SCALE[Units.nm.value]
+                area_array=segmentation[0] == 1, voxel_size=image.voxel_size, result_scalar=UNIT_SCALE[Units.nm.value]
             ),
             Sphericity.calculate_property(
-                area_array=segmentation == 2, voxel_size=image.voxel_size, result_scalar=UNIT_SCALE[Units.nm.value]
+                area_array=segmentation[0] == 2, voxel_size=image.voxel_size, result_scalar=UNIT_SCALE[Units.nm.value]
             ),
         ]
         assert result["LongestMainAxisLength"][0] == 55 * 50 * UNIT_SCALE[Units.nm.value]
@@ -1735,29 +1758,38 @@ class TestStatisticProfile:
         assert os.path.exists(file_path)
         profile = load_metadata(file_path)["all_statistic"]
         image = get_two_components_image()
-        mask = get_two_component_mask()
-        segmentation = np.zeros(mask.shape, dtype=np.uint8)
-        segmentation[image.get_channel(0)[0] == 50] = 1
-        segmentation[image.get_channel(0)[0] == 60] = 2
+        image.set_mask(get_two_component_mask())
+        segmentation = np.zeros(image.mask.shape, dtype=np.uint8)
+        segmentation[image.get_channel(0) == 50] = 1
+        segmentation[image.get_channel(0) == 60] = 2
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.nm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.nm,
         )
         names = {x.name for x in profile.chosen_fields}
         assert names == set(result.keys())
 
     def test_proportion(self):
         image = get_two_components_image()
-        mask = get_two_component_mask()
-        segmentation = np.zeros(mask.shape, dtype=np.uint8)
-        segmentation[image.get_channel(0)[0] == 50] = 1
-        segmentation[image.get_channel(0)[0] == 60] = 2
+        image.set_mask(get_two_component_mask())
+        segmentation = np.zeros(image.mask.shape, dtype=np.uint8)
+        segmentation[image.get_channel(0) == 50] = 1
+        segmentation[image.get_channel(0) == 60] = 2
         leaf1 = Volume.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.Yes)
         leaf2 = Volume.get_starting_leaf().replace_(area=AreaType.Mask, per_component=PerComponent.Yes)
         leaf3 = Volume.get_starting_leaf().replace_(area=AreaType.Mask_without_ROI, per_component=PerComponent.Yes)
         leaf4 = PixelBrightnessSum.get_starting_leaf().replace_(area=AreaType.ROI, per_component=PerComponent.Yes)
         statistics = [
-            MeasurementEntry("ROI Volume per component", leaf1,),
-            MeasurementEntry("Mask Volume per component", leaf2,),
+            MeasurementEntry(
+                "ROI Volume per component",
+                leaf1,
+            ),
+            MeasurementEntry(
+                "Mask Volume per component",
+                leaf2,
+            ),
             MeasurementEntry("ROI Volume per component/Mask Volume per component", Node(leaf1, "/", leaf2)),
             MeasurementEntry("Mask Volume per component/ROI Volume per component", Node(leaf2, "/", leaf1)),
             MeasurementEntry(
@@ -1767,7 +1799,10 @@ class TestStatisticProfile:
         ]
         profile = MeasurementProfile("statistic", statistics)
         result = profile.calculate(
-            image.get_channel(0), segmentation, mask=mask, voxel_size=image.voxel_size, result_units=Units.nm,
+            image,
+            0,
+            segmentation,
+            result_units=Units.nm,
         )
         # TODO check values
         assert len(result["ROI Volume per component/Mask Volume per component"][0]) == 2
